.. _bokeh.core.enums:

bokeh.core.enums
----------------

.. enumeration is excluded below so that it can be explicitly
.. included earlier in the module docstring

.. automodule:: bokeh.core.enums
  :members:
  :undoc-members:
  :exclude-members: enumeration
